@@ -90,7 +90,7 @@ gl_label_object_get_type (void)
 	static GType type = 0;
 
 	if (!type) {
-		GTypeInfo info = {
+		static const GTypeInfo info = {
 			sizeof (glLabelObjectClass),
 			NULL,
 			NULL,
@@ -100,6 +100,7 @@ gl_label_object_get_type (void)
 			sizeof (glLabelObject),
 			0,
 			(GInstanceInitFunc) gl_label_object_instance_init,
+			NULL
 		};
 
 		type = g_type_register_static (G_TYPE_OBJECT,
