@@ -45,6 +45,7 @@ struct _glLabelPrivate {
         gboolean     rotate_flag;
 
 	gchar       *filename;
+	gint         compression;
 	gboolean     modified_flag;
 	gint         untitled_instance;
 
@@ -98,7 +99,7 @@ gl_label_get_type (void)
 	static GType type = 0;
 
 	if (!type) {
-		GTypeInfo info = {
+		static const GTypeInfo info = {
 			sizeof (glLabelClass),
 			NULL,
 			NULL,
@@ -108,6 +109,7 @@ gl_label_get_type (void)
 			sizeof (glLabel),
 			0,
 			(GInstanceInitFunc) gl_label_instance_init,
+			NULL
 		};
 
 		type = g_type_register_static (G_TYPE_OBJECT,
@@ -230,6 +232,8 @@ gl_label_new (void)
 
 	label = g_object_new (gl_label_get_type(), NULL);
 
+	label->private->compression = 9;
+
 	label->private->modified_flag = FALSE;
 
 	gl_debug (DEBUG_LABEL, "END");
@@ -654,4 +658,33 @@ gl_label_clear_modified (glLabel *label)
 }
 
 
+/****************************************************************************/
+/* Set compression level.                                                   */
+/****************************************************************************/
+void
+gl_label_set_compression (glLabel  *label,
+			  gint      compression)
+{
+	gl_debug (DEBUG_LABEL, "set %d", compression);
+
+	/* Older versions of libxml2 always return a -1 for documents "read in," so
+	 * default to 9.  Also, default to 9 for anything else out of range. */
+	if ((compression < 0) || (compression >9)) {
+		compression = 9;
+	}
+
+	gl_debug (DEBUG_LABEL, "actual set %d", compression);
+	label->private->compression = compression;
+}
+
+
+/****************************************************************************/
+/* Get compression level.                                                   */
+/****************************************************************************/
+gint
+gl_label_get_compression (glLabel *label)
+{
+	gl_debug (DEBUG_LABEL, "return %d", label->private->compression);
+	return label->private->compression;
+}
 
