@@ -233,7 +233,7 @@ gl_merge_get_type (void)
 	static GType type = 0;
 
 	if (!type) {
-		GTypeInfo info = {
+		static const GTypeInfo info = {
 			sizeof (glMergeClass),
 			NULL,
 			NULL,
@@ -243,6 +243,7 @@ gl_merge_get_type (void)
 			sizeof (glMerge),
 			0,
 			(GInstanceInitFunc) gl_merge_instance_init,
+			NULL
 		};
 
 		type = g_type_register_static (G_TYPE_OBJECT,
