@@ -64,8 +64,6 @@ gl_object_editor_prepare_size_page (glObjectEditor       *editor,
 	const gchar  *units_string;
 	gdouble       climb_rate;
 	gint          digits;
-	GtkSizeGroup *label_size_group;
-	GtkWidget    *label;
 
 	gl_debug (DEBUG_EDITOR, "START");
 
@@ -101,13 +99,6 @@ gl_object_editor_prepare_size_page (glObjectEditor       *editor,
 					climb_rate, 10.0*climb_rate);
 	gtk_label_set_text (GTK_LABEL(editor->priv->size_h_units_label), units_string);
 
-	/* Align label widths */
-	label_size_group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
-	label = glade_xml_get_widget (editor->priv->gui, "size_w_label");
-	gtk_size_group_add_widget (label_size_group, label);
-	label = glade_xml_get_widget (editor->priv->gui, "size_h_label");
-	gtk_size_group_add_widget (label_size_group, label);
-
 	/* Un-hide */
 	gtk_widget_show_all (editor->priv->size_page_vbox);
 	if (option != GL_OBJECT_EDITOR_SIZE_IMAGE_PAGE) {
@@ -120,11 +111,11 @@ gl_object_editor_prepare_size_page (glObjectEditor       *editor,
 				  G_CALLBACK (aspect_toggle_cb),
 				  G_OBJECT (editor));
 	g_signal_connect_swapped (G_OBJECT (editor->priv->size_w_spin),
-				  "value-changed",
+				  "changed",
 				  G_CALLBACK (w_spin_cb),
 				  G_OBJECT (editor));
 	g_signal_connect_swapped (G_OBJECT (editor->priv->size_h_spin),
-				  "value-changed",
+				  "changed",
 				  G_CALLBACK (h_spin_cb),
 				  G_OBJECT (editor));
 
