@@ -60,8 +60,6 @@ void
 gl_object_editor_prepare_text_page (glObjectEditor       *editor)
 {
 	GList        *family_names = NULL;
-	GtkSizeGroup *label_size_group;
-	GtkWidget    *label;
 
 	gl_debug (DEBUG_EDITOR, "START");
 
@@ -88,6 +86,8 @@ gl_object_editor_prepare_text_page (glObjectEditor       *editor)
 		glade_xml_get_widget (editor->priv->gui, "text_right_toggle");
 	editor->priv->text_line_spacing_spin =
 		glade_xml_get_widget (editor->priv->gui, "text_line_spacing_spin");
+	editor->priv->text_auto_shrink_check =
+		glade_xml_get_widget (editor->priv->gui, "text_auto_shrink_check");
 
 	/* Load family names */
 	family_names = gnome_font_family_list ();
@@ -95,21 +95,6 @@ gl_object_editor_prepare_text_page (glObjectEditor       *editor)
 				       family_names);
 	gnome_font_family_list_free (family_names);
 
-	/* Align label widths */
-	label_size_group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
-	label = glade_xml_get_widget (editor->priv->gui, "text_family_label");
-	gtk_size_group_add_widget (label_size_group, label);
-	label = glade_xml_get_widget (editor->priv->gui, "text_size_label");
-	gtk_size_group_add_widget (label_size_group, label);
-	label = glade_xml_get_widget (editor->priv->gui, "text_style_label");
-	gtk_size_group_add_widget (label_size_group, label);
-	label = glade_xml_get_widget (editor->priv->gui, "text_color_label");
-	gtk_size_group_add_widget (label_size_group, label);
-	label = glade_xml_get_widget (editor->priv->gui, "text_align_label");
-	gtk_size_group_add_widget (label_size_group, label);
-	label = glade_xml_get_widget (editor->priv->gui, "text_line_spacing_label");
-	gtk_size_group_add_widget (label_size_group, label);
-
 	/* Un-hide */
 	gtk_widget_show_all (editor->priv->text_page_vbox);
 
@@ -153,6 +138,11 @@ gl_object_editor_prepare_text_page (glObjectEditor       *editor)
 				  G_CALLBACK (gl_object_editor_changed_cb),
 				  G_OBJECT (editor));
 
+	g_signal_connect_swapped (G_OBJECT (editor->priv->text_auto_shrink_check),
+				  "toggled",
+				  G_CALLBACK (gl_object_editor_changed_cb),
+				  G_OBJECT (editor));
+
 	gl_debug (DEBUG_EDITOR, "END");
 }
 
@@ -546,3 +536,43 @@ gl_object_editor_get_text_line_spacing (glObjectEditor      *editor)
 	return text_line_spacing;
 }
 
+/*****************************************************************************/
+/* Set auto shrink checkbox.                                                 */
+/*****************************************************************************/
+void
+gl_object_editor_set_text_auto_shrink (glObjectEditor      *editor,
+				       gboolean             auto_shrink)
+{
+	gl_debug (DEBUG_EDITOR, "START");
+
+	g_signal_handlers_block_by_func (G_OBJECT(editor->priv->text_auto_shrink_check),
+					 gl_object_editor_changed_cb,
+					 editor);
+
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (editor->priv->text_auto_shrink_check),
+                                      auto_shrink);
+
+	g_signal_handlers_unblock_by_func (G_OBJECT(editor->priv->text_auto_shrink_check),
+					   gl_object_editor_changed_cb,
+					   editor);
+
+	gl_debug (DEBUG_EDITOR, "END");
+}
+
+/*****************************************************************************/
+/* Query auto shrink checkbox.                                               */
+/*****************************************************************************/
+gboolean    gl_object_editor_get_text_auto_shrink (glObjectEditor      *editor)
+{
+	gboolean auto_shrink;
+
+	gl_debug (DEBUG_EDITOR, "START");
+
+	auto_shrink = 
+		gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (editor->priv->text_auto_shrink_check));
+
+	gl_debug (DEBUG_EDITOR, "END");
+
+	return auto_shrink;
+}
+
