@@ -95,7 +95,7 @@ gl_view_object_get_type (void)
 	static GType type = 0;
 
 	if (!type) {
-		GTypeInfo info = {
+		static const GTypeInfo info = {
 			sizeof (glViewObjectClass),
 			NULL,
 			NULL,
@@ -105,6 +105,7 @@ gl_view_object_get_type (void)
 			sizeof (glViewObject),
 			0,
 			(GInstanceInitFunc) gl_view_object_instance_init,
+			NULL
 		};
 
 		type = g_type_register_static (G_TYPE_OBJECT,
