@@ -546,7 +546,7 @@ xml191_parse_barcode_props (xmlNodePtr  node,
 
 	gl_label_barcode_set_data (GL_LABEL_BARCODE(object), text_node);
 	gl_label_barcode_set_props (GL_LABEL_BARCODE(object),
-				    id, text_flag, checksum_flag);
+				    id, text_flag, checksum_flag, 0);
 	gl_label_object_set_line_color (GL_LABEL_OBJECT(object), color);
 
 	gl_text_node_free (&text_node);
@@ -695,7 +695,16 @@ xml191_parse_sheet (xmlNodePtr sheet_node)
 
 	description = xmlGetProp (sheet_node, "_description");
 	if (description != NULL) {
-		template->description = gettext (description);
+
+		gchar *tmp = gettext (description);
+
+		if (tmp == description) {
+			template->description = description;
+		} else {
+			template->description = g_strdup (tmp);
+		}
+
+
 	} else {
 		template->description = xmlGetProp (sheet_node, "description");
 	}
@@ -760,7 +769,7 @@ xml191_parse_label (xmlNodePtr  label_node,
 		h = gl_xml_get_prop_length (label_node, "height", 0);
 		r = gl_xml_get_prop_length (label_node, "round", 0);
 		label_type =
-			gl_template_rect_label_type_new ("0", w, h, r, 0.0);
+			gl_template_rect_label_type_new ("0", w, h, r, 0.0, 0.0);
 		break;
 
 	case GL_TEMPLATE_SHAPE_ROUND:
