@@ -255,6 +255,8 @@ xml_doc_to_label (xmlDocPtr         doc,
 	ns = xmlSearchNsByHref (doc, root, GL_XML_NAME_SPACE);
 	if (ns != NULL) {
 		label = xml_parse_label (root, status);
+		if (label)
+			gl_label_set_compression (label, xmlGetDocCompressMode (doc));
 	} else {
 		/* Try compatability mode 0.1 */
 		ns = xmlSearchNsByHref (doc, root, COMPAT01_NAME_SPACE);
@@ -409,6 +411,7 @@ xml_parse_object_text (xmlNodePtr  node,
 	gdouble           w, h;
 	gchar            *string;
 	GtkJustification  just;
+	gboolean          auto_shrink;
 	gdouble           affine[6];
 	xmlNodePtr        child;
 
@@ -432,6 +435,10 @@ xml_parse_object_text (xmlNodePtr  node,
 	g_free (string);
 	gl_label_object_set_text_alignment (GL_LABEL_OBJECT(object), just);
 
+	/* auto_shrink attr */
+	auto_shrink = gl_xml_get_prop_boolean (node, "auto_shrink", FALSE);
+	gl_label_text_set_auto_shrink (GL_LABEL_TEXT(object), auto_shrink);
+
 	/* affine attrs */
 	affine[0] = gl_xml_get_prop_double (node, "a0", 0.0);
 	affine[1] = gl_xml_get_prop_double (node, "a1", 0.0);
@@ -680,6 +687,7 @@ xml_parse_object_barcode (xmlNodePtr  node,
 	gboolean            text_flag;
 	gboolean            checksum_flag;
 	guint               color;
+	guint               format_digits;
 	gdouble             affine[6];
 
 	gl_debug (DEBUG_XML, "START");
@@ -701,8 +709,9 @@ xml_parse_object_barcode (xmlNodePtr  node,
 	text_flag = gl_xml_get_prop_boolean (node, "text", FALSE);
 	checksum_flag = gl_xml_get_prop_boolean (node, "checksum", TRUE);
 	color = gl_xml_get_prop_uint (node, "color", 0);
+	format_digits = gl_xml_get_prop_uint (node, "format", 10);
 	gl_label_barcode_set_props (GL_LABEL_BARCODE(object),
-				    id, text_flag, checksum_flag);
+				    id, text_flag, checksum_flag, format_digits);
 	gl_label_object_set_line_color (GL_LABEL_OBJECT(object), color);
 	g_free (id);
 
@@ -952,7 +961,7 @@ gl_xml_label_save (glLabel          *label,
 	if (!filename)
 		g_warning (_("Utf8 conversion error."));
 	else {
-		xmlSetDocCompressMode (doc, 9);
+		xmlSetDocCompressMode (doc, gl_label_get_compression (label));
 		xml_ret = xmlSaveFormatFile (filename, doc, TRUE);
 		xmlFreeDoc (doc);
 		if (xml_ret == -1) {
@@ -1097,6 +1106,7 @@ xml_create_object_text (xmlNodePtr     root,
 	gdouble           x, y;
 	gdouble           w, h;
 	GtkJustification  just;
+	gboolean          auto_shrink;
 	gdouble           affine[6];
 
 	gl_debug (DEBUG_XML, "START");
@@ -1117,6 +1127,10 @@ xml_create_object_text (xmlNodePtr     root,
 	just = gl_label_object_get_text_alignment (object);
 	xmlSetProp (node, "justify", gl_util_just_to_string (just));
 
+	/* auto_shrink attr */
+	auto_shrink = gl_label_text_get_auto_shrink (GL_LABEL_TEXT (object));
+	gl_xml_set_prop_boolean (node, "auto_shrink", auto_shrink);
+
 	/* affine attrs */
 	gl_label_object_get_affine (object, affine);
 	gl_xml_set_prop_double (node, "a0", affine[0]);
@@ -1346,6 +1360,7 @@ xml_create_object_barcode (xmlNodePtr     root,
 	gboolean          text_flag;
 	gboolean          checksum_flag;
 	guint             color;
+	guint             format_digits;
 	gdouble           affine[6];
 
 	gl_debug (DEBUG_XML, "START");
@@ -1364,7 +1379,7 @@ xml_create_object_barcode (xmlNodePtr     root,
 
 	/* Barcode properties attrs */
 	gl_label_barcode_get_props (GL_LABEL_BARCODE(object),
-				    &id, &text_flag, &checksum_flag);
+				    &id, &text_flag, &checksum_flag, &format_digits);
 	color = gl_label_object_get_line_color (GL_LABEL_OBJECT(object));
 	xmlSetProp (node, "style", id);
 	gl_xml_set_prop_boolean (node, "text", text_flag);
@@ -1376,6 +1391,7 @@ xml_create_object_barcode (xmlNodePtr     root,
 	text_node = gl_label_barcode_get_data (GL_LABEL_BARCODE(object));
 	if (text_node->field_flag) {
 		xmlSetProp (node, "field", text_node->data);
+	        gl_xml_set_prop_int (node, "format", format_digits);
 	} else {
 		xmlSetProp (node, "data", text_node->data);
 	}
